@@ -24,8 +24,8 @@ SETI_DEVELOP = "https://api-ve74dbrnra-uc.a.run.app/"
 
 class Seti():
 
-    def __init__(self, path_to_private_key: str, api_key: str, public_key='', seti_path=SETI_DEVELOP) -> (None):
-        self.private_key = path_to_private_key
+    def __init__(self, private_key: str, api_key: str, public_key='', seti_path=SETI_DEVELOP) -> (None):
+        self.private_key = private_key
         self.api_key = api_key
         self.public_key_loc = public_key
         self.seti_path = seti_path
@@ -62,19 +62,21 @@ class Seti():
         buffered_data = execjs.eval(
             "Buffer.from(JSON.stringify({}))".format(data))
         bytesData = bytearray(buffered_data['data'])
-        key = open(self.private_key, "r").read()
-        rsakey = RSA.importKey(key, self.api_key)
+        rsakey = RSA.importKey(self.private_key)
         hash = SHA256.new(bytesData)
         cipher_rsa = PKCS1_v1_5.new(rsakey)
         return b64encode(cipher_rsa.sign(hash)).decode("utf-8")
 
     def send_request(self, data: dict, sign_data: str, path: str):
-        url = self.seti_path+path
-        r = requests.post(url=url, json=data, headers={
-            "authorization": self.api_key,
-            "sign": sign_data
-        }, timeout=10)
-        return r.json()
+        try:
+            url = self.seti_path+path
+            r = requests.post(url=url, json=data, headers={
+                "authorization": self.api_key,
+                "sign": sign_data
+            }, timeout=10)
+            return r.json()
+        except Exception as e:
+            return {'msg': str(e), 'code': 5}
 
     def validate_currency(self, currency: str):
         if not currency in ["COP", "USD", "EUR"]:
